/**
 * MojoELF; load ELF binaries from a memory buffer.
 *
 * Please see the file LICENSE.txt in the source's root directory.
 *
 *  This file written by Ryan C. Gordon.
 */

// Do not #pragma once this file, it's intentionally included multiple times.

// This started as a dump of eglibc's conform/data directory (see dumpfn.pl).
// Some of these are commented out because they aren't going to be safe to
// directly passthrough (ioctl), some have structs that need to be converted
// (stat), some probably don't exist or are just not something I know about.
// Add back in what's appropriate, write some bridge functions for the rest.

// Variations on printf/scanf that are largely macro glue.
// !!! FIXME: GNU's *scanf() expects "%a" to allocate data. Mac's doesn't do that.
MACTRAMPOLINE_PRINTF(printf, (const char *fmt, ...), (fmt, ap))
MACTRAMPOLINE_PRINTF(fprintf, (FILE *io, const char *fmt, ...), (io, fmt, ap))
MACTRAMPOLINE_PRINTF(sprintf, (char *str, const char *fmt, ...), (str, fmt, ap))
MACTRAMPOLINE_PRINTF(snprintf, (char *str, size_t len, const char *fmt, ...), (str, len, fmt, ap))
MACTRAMPOLINE_PRINTF(asprintf, (char **ret, const char *fmt, ...), (ret, fmt, ap))
MACTRAMPOLINE_PRINTF(dprintf, (int fd, const char *fmt, ...), (fd, fmt, ap))
MACTRAMPOLINE_PRINTF(fwprintf,(FILE *io, const wchar_t *fmt, ...), (io, fmt, ap))
MACTRAMPOLINE_PRINTF(fwscanf,(FILE *io, const wchar_t *fmt, ...), (io, fmt, ap))
MACTRAMPOLINE_PRINTF(swprintf,(wchar_t *str, size_t len, const wchar_t *fmt, ...), (str, len, fmt, ap))
MACTRAMPOLINE_PRINTF(swscanf,(const wchar_t *str, const wchar_t *fmt, ...), (str, fmt, ap))
MACTRAMPOLINE_PRINTF(wprintf,(const wchar_t *fmt, ...), (fmt, ap))
MACTRAMPOLINE_PRINTF(wscanf,(const wchar_t *fmt, ...), (fmt, ap))
MACTRAMPOLINE_PRINTF(sscanf,(const char *str, const char *fmt, ...), (str, fmt, ap))
MACTRAMPOLINE_PRINTF(fscanf,(FILE *io, const char *fmt, ...), (io, fmt, ap))
MACTRAMPOLINE_PRINTF(scanf,(const char *fmt, ...), (fmt, ap))

// Entry points we define ourselves without any macro glue.
MACTRAMPOLINE_OVERRIDE(__libc_start_main)
MACTRAMPOLINE_OVERRIDE(__errno_location)
MACTRAMPOLINE_OVERRIDE(__cxa_atexit)
MACTRAMPOLINE_OVERRIDE(__cxa_finalize)
MACTRAMPOLINE_OVERRIDE(__ctype_get_mb_cur_max)
MACTRAMPOLINE_OVERRIDE(__fprintf_chk)
MACTRAMPOLINE_OVERRIDE(__printf_chk)
MACTRAMPOLINE_OVERRIDE(__sprintf_chk)
MACTRAMPOLINE_OVERRIDE(__vsnprintf_chk)
MACTRAMPOLINE_OVERRIDE(__vasprintf_chk)
MACTRAMPOLINE_OVERRIDE(__vfprintf_chk)
MACTRAMPOLINE_OVERRIDE(__strcat_chk)
MACTRAMPOLINE_OVERRIDE(__strncat_chk)
MACTRAMPOLINE_OVERRIDE(__memset_chk)
MACTRAMPOLINE_OVERRIDE(__memmove_chk)
MACTRAMPOLINE_OVERRIDE(__memcpy_chk)
MACTRAMPOLINE_OVERRIDE(__rawmemchr)
MACTRAMPOLINE_OVERRIDE(__strcpy_chk)
MACTRAMPOLINE_OVERRIDE(__strncpy_chk)
MACTRAMPOLINE_OVERRIDE(__snprintf_chk)
MACTRAMPOLINE_OVERRIDE(__isoc99_scanf)
MACTRAMPOLINE_OVERRIDE(__isoc99_fscanf)
MACTRAMPOLINE_OVERRIDE(__isoc99_sscanf)
MACTRAMPOLINE_OVERRIDE(__strtod_internal)
MACTRAMPOLINE_OVERRIDE(__strtol_internal)
MACTRAMPOLINE_OVERRIDE(__strtoul_internal)
MACTRAMPOLINE_OVERRIDE(__bcopy)
MACTRAMPOLINE_OVERRIDE(__bzero)
MACTRAMPOLINE_OVERRIDE(__xpg_basename)
MACTRAMPOLINE_OVERRIDE(_IO_putc)
MACTRAMPOLINE_OVERRIDE(_IO_getc)
MACTRAMPOLINE_OVERRIDE(fputs_unlocked)
MACTRAMPOLINE_OVERRIDE(fwrite_unlocked)
MACTRAMPOLINE_OVERRIDE(creat)
MACTRAMPOLINE_OVERRIDE(shm_open)
MACTRAMPOLINE_OVERRIDE(chmod)
MACTRAMPOLINE_OVERRIDE(fchmod)
MACTRAMPOLINE_OVERRIDE(mkdir)
MACTRAMPOLINE_OVERRIDE(mkfifo)
MACTRAMPOLINE_OVERRIDE(mknod)
MACTRAMPOLINE_OVERRIDE(umask)
MACTRAMPOLINE_OVERRIDE(dlopen)
MACTRAMPOLINE_OVERRIDE(dlsym)
MACTRAMPOLINE_OVERRIDE(dlclose)
MACTRAMPOLINE_OVERRIDE(dlerror)
MACTRAMPOLINE_OVERRIDE(open)
MACTRAMPOLINE_OVERRIDE(open64)
MACTRAMPOLINE_OVERRIDE(fopen64)
MACTRAMPOLINE_OVERRIDE(ftruncate)
MACTRAMPOLINE_OVERRIDE(lseek)
MACTRAMPOLINE_OVERRIDE(lseek64)
MACTRAMPOLINE_OVERRIDE(pread)
MACTRAMPOLINE_OVERRIDE(pwrite)
MACTRAMPOLINE_OVERRIDE(truncate)
MACTRAMPOLINE_OVERRIDE(mmap)
MACTRAMPOLINE_OVERRIDE(fseeko)
MACTRAMPOLINE_OVERRIDE(ftello)
MACTRAMPOLINE_OVERRIDE(fseeko64)
MACTRAMPOLINE_OVERRIDE(ftello64)
MACTRAMPOLINE_OVERRIDE(bindtextdomain)
MACTRAMPOLINE_OVERRIDE(textdomain)
MACTRAMPOLINE_OVERRIDE(dcgettext)
MACTRAMPOLINE_OVERRIDE(__ctype_b_loc)
MACTRAMPOLINE_OVERRIDE(__ctype_tolower_loc)
MACTRAMPOLINE_OVERRIDE(__ctype_toupper_loc)
MACTRAMPOLINE_OVERRIDE(mbsinit)
MACTRAMPOLINE_OVERRIDE(setlocale)
MACTRAMPOLINE_OVERRIDE(nl_langinfo)
MACTRAMPOLINE_OVERRIDE(__stack_chk_fail)
MACTRAMPOLINE_OVERRIDE(__fpending)
MACTRAMPOLINE_OVERRIDE(error)
MACTRAMPOLINE_OVERRIDE(__strdup)
MACTRAMPOLINE_OVERRIDE(ioctl)
MACTRAMPOLINE_OVERRIDE(fcntl)
MACTRAMPOLINE_OVERRIDE(opendir)
MACTRAMPOLINE_OVERRIDE(readdir)
MACTRAMPOLINE_OVERRIDE(readdir64)
MACTRAMPOLINE_OVERRIDE(readdir_r)
MACTRAMPOLINE_OVERRIDE(readdir64_r)
MACTRAMPOLINE_OVERRIDE(rewinddir)
MACTRAMPOLINE_OVERRIDE(seekdir)
MACTRAMPOLINE_OVERRIDE(telldir)
MACTRAMPOLINE_OVERRIDE(closedir)
MACTRAMPOLINE_OVERRIDE(__assert_fail)
MACTRAMPOLINE_OVERRIDE(waitpid)
MACTRAMPOLINE_OVERRIDE(_setjmp)
MACTRAMPOLINE_OVERRIDE(_longjmp)
MACTRAMPOLINE_OVERRIDE(__sigsetjmp)
MACTRAMPOLINE_OVERRIDE(stat)
MACTRAMPOLINE_OVERRIDE(lstat)
MACTRAMPOLINE_OVERRIDE(fstat)
MACTRAMPOLINE_OVERRIDE(__xstat)
MACTRAMPOLINE_OVERRIDE(__lxstat)
MACTRAMPOLINE_OVERRIDE(__fxstat)
MACTRAMPOLINE_OVERRIDE(__xstat64)
MACTRAMPOLINE_OVERRIDE(__lxstat64)
MACTRAMPOLINE_OVERRIDE(__fxstat64)
MACTRAMPOLINE_OVERRIDE(mkstemp64)
MACTRAMPOLINE_OVERRIDE(uname)
MACTRAMPOLINE_OVERRIDE(glob)
MACTRAMPOLINE_OVERRIDE(globfree)
MACTRAMPOLINE_OVERRIDE(getrlimit)
MACTRAMPOLINE_OVERRIDE(getrlimit64)
MACTRAMPOLINE_OVERRIDE(setrlimit)
MACTRAMPOLINE_OVERRIDE(setrlimit64)
MACTRAMPOLINE_OVERRIDE(pthread_attr_destroy)
MACTRAMPOLINE_OVERRIDE(pthread_attr_getdetachstate)
MACTRAMPOLINE_OVERRIDE(pthread_attr_getguardsize)
MACTRAMPOLINE_OVERRIDE(pthread_attr_getinheritsched)
MACTRAMPOLINE_OVERRIDE(pthread_attr_getschedpolicy)
MACTRAMPOLINE_OVERRIDE(pthread_attr_getscope)
MACTRAMPOLINE_OVERRIDE(pthread_attr_getstackaddr)
MACTRAMPOLINE_OVERRIDE(pthread_attr_getstacksize)
MACTRAMPOLINE_OVERRIDE(pthread_attr_init)
MACTRAMPOLINE_OVERRIDE(pthread_attr_setdetachstate)
MACTRAMPOLINE_OVERRIDE(pthread_attr_setguardsize)
MACTRAMPOLINE_OVERRIDE(pthread_attr_setinheritsched)
MACTRAMPOLINE_OVERRIDE(pthread_attr_setschedpolicy)
MACTRAMPOLINE_OVERRIDE(pthread_attr_setscope)
MACTRAMPOLINE_OVERRIDE(pthread_attr_setstackaddr)
MACTRAMPOLINE_OVERRIDE(pthread_attr_setstacksize)
MACTRAMPOLINE_OVERRIDE(pthread_cond_broadcast)
MACTRAMPOLINE_OVERRIDE(pthread_cond_destroy)
MACTRAMPOLINE_OVERRIDE(pthread_cond_init)
MACTRAMPOLINE_OVERRIDE(pthread_cond_signal)
MACTRAMPOLINE_OVERRIDE(pthread_cond_timedwait)
MACTRAMPOLINE_OVERRIDE(pthread_cond_wait)
MACTRAMPOLINE_OVERRIDE(pthread_condattr_destroy)
MACTRAMPOLINE_OVERRIDE(pthread_condattr_getpshared)
MACTRAMPOLINE_OVERRIDE(pthread_condattr_init)
MACTRAMPOLINE_OVERRIDE(pthread_condattr_setpshared)
MACTRAMPOLINE_OVERRIDE(pthread_create)
MACTRAMPOLINE_OVERRIDE(pthread_getspecific)
MACTRAMPOLINE_OVERRIDE(pthread_setspecific)
MACTRAMPOLINE_OVERRIDE(pthread_key_create)
MACTRAMPOLINE_OVERRIDE(pthread_key_delete)
MACTRAMPOLINE_OVERRIDE(pthread_once)
MACTRAMPOLINE_OVERRIDE(pthread_mutex_destroy)
MACTRAMPOLINE_OVERRIDE(pthread_mutex_init)
MACTRAMPOLINE_OVERRIDE(pthread_mutex_lock)
MACTRAMPOLINE_OVERRIDE(pthread_mutex_trylock)
MACTRAMPOLINE_OVERRIDE(pthread_mutex_unlock)
MACTRAMPOLINE_OVERRIDE(pthread_mutexattr_destroy)
MACTRAMPOLINE_OVERRIDE(pthread_mutexattr_getpshared)
MACTRAMPOLINE_OVERRIDE(pthread_mutexattr_gettype)
MACTRAMPOLINE_OVERRIDE(pthread_mutexattr_init)
MACTRAMPOLINE_OVERRIDE(pthread_mutexattr_setpshared)
MACTRAMPOLINE_OVERRIDE(pthread_mutexattr_settype)
MACTRAMPOLINE_OVERRIDE(pthread_mutexattr_setkind_np)
MACTRAMPOLINE_OVERRIDE(pthread_rwlock_init)
MACTRAMPOLINE_OVERRIDE(pthread_rwlock_destroy)
MACTRAMPOLINE_OVERRIDE(pthread_rwlock_rdlock)
MACTRAMPOLINE_OVERRIDE(pthread_rwlock_tryrdlock)
MACTRAMPOLINE_OVERRIDE(pthread_rwlock_trywrlock)
MACTRAMPOLINE_OVERRIDE(pthread_rwlock_unlock)
MACTRAMPOLINE_OVERRIDE(pthread_rwlock_wrlock)
MACTRAMPOLINE_OVERRIDE(pthread_rwlockattr_destroy)
MACTRAMPOLINE_OVERRIDE(pthread_rwlockattr_getpshared)
MACTRAMPOLINE_OVERRIDE(pthread_rwlockattr_init)
MACTRAMPOLINE_OVERRIDE(pthread_rwlockattr_setpshared)
MACTRAMPOLINE_OVERRIDE(pthread_sigmask)

//MACTRAMPOLINE_OVERRIDE(pthread_attr_getschedparam)
//MACTRAMPOLINE_OVERRIDE(pthread_attr_setschedparam)
//MACTRAMPOLINE_OVERRIDE(pthread_getschedparam)
//MACTRAMPOLINE(int,pthread_setschedparam,(pthread_t a, int b, const struct sched_param *c),(a,b,c),return)


// These just work as-is (pthread_t matches closely enough).
// !!! FIXME: the errors need converting, though.  :(
MACTRAMPOLINE(int,pthread_cancel,(pthread_t a),(a),return)
MACTRAMPOLINE(int,pthread_join,(pthread_t a, void **b),(a,b),return)
MACTRAMPOLINE(void,pthread_testcancel,(void),(),)
MACTRAMPOLINE(int,pthread_atfork,(void(*a)(void),void(*b)(void),void(*c)(void)),(a,b,c),return)
MACTRAMPOLINE(pthread_t,pthread_self,(void),(),return)
MACTRAMPOLINE(int,pthread_detach,(pthread_t a),(a),return)
MACTRAMPOLINE(int,pthread_equal,(pthread_t a, pthread_t b),(a,b),return)
MACTRAMPOLINE(void,pthread_exit,(void *a),(a),)
MACTRAMPOLINE(int,pthread_setconcurrency,(int a),(a),return)  // !!! FIXME: check these values.
MACTRAMPOLINE(int,pthread_getconcurrency,(void),(),return)  // !!! FIXME: check these values.
MACTRAMPOLINE(int,pthread_setcancelstate,(int a, int *b),(a,b),return)  // !!! FIXME: check these values.
MACTRAMPOLINE(int,pthread_setcanceltype,(int a, int *b),(a,b),return)  // !!! FIXME: check these values.

// These don't exist as of Mac OS X 10.8.
//MACTRAMPOLINE(int,pthread_barrier_destroy,(pthread_barrier_t *a),(a),return)
//MACTRAMPOLINE(int,pthread_barrier_init,(pthread_barrier_t *a, const pthread_barrierattr_t *b, unsigned int c),(a,b,c),return)
//MACTRAMPOLINE(int,pthread_barrier_wait,(pthread_barrier_t *a),(a),return)
//MACTRAMPOLINE(int,pthread_barrierattr_destroy,(pthread_barrierattr_t *a),(a),return)
//MACTRAMPOLINE(int,pthread_barrierattr_getpshared,(const pthread_barrierattr_t *a, int *b),(a,b),return)
//MACTRAMPOLINE(int,pthread_barrierattr_init,(pthread_barrierattr_t *a),(a),return)
//MACTRAMPOLINE(int,pthread_barrierattr_setpshared,(pthread_barrierattr_t *a, int b),(a,b),return)
//MACTRAMPOLINE(int,pthread_getcpuclockid,(pthread_t a, clockid_t *b),(a,b),return)
//MACTRAMPOLINE(int,pthread_spin_destroy,(pthread_spinlock_t *a),(a),return)
//MACTRAMPOLINE(int,pthread_spin_init,(pthread_spinlock_t *a, int b),(a,b),return)
//MACTRAMPOLINE(int,pthread_spin_lock,(pthread_spinlock_t *a),(a),return)
//MACTRAMPOLINE(int,pthread_spin_trylock,(pthread_spinlock_t *a),(a),return)
//MACTRAMPOLINE(int,pthread_spin_unlock,(pthread_spinlock_t *a),(a),return)
//MACTRAMPOLINE_OVERRIDE(pthread_mutex_timedlock)
//MACTRAMPOLINE_OVERRIDE(pthread_rwlock_timedrdlock)
//MACTRAMPOLINE_OVERRIDE(pthread_rwlock_timedwrlock)

MACTRAMPOLINE_OVERRIDE(getpwnam)
MACTRAMPOLINE_OVERRIDE(getpwuid)
MACTRAMPOLINE_OVERRIDE(getpwnam_r)
MACTRAMPOLINE_OVERRIDE(getpwuid_r)
MACTRAMPOLINE_OVERRIDE(getpwent)

MACTRAMPOLINE_OVERRIDE(sincos)
MACTRAMPOLINE_OVERRIDE(sincosf)
MACTRAMPOLINE_OVERRIDE(sincosl)
MACTRAMPOLINE_OVERRIDE(__sin_finite)
MACTRAMPOLINE_OVERRIDE(__sinf_finite)
MACTRAMPOLINE_OVERRIDE(__sinl_finite)
MACTRAMPOLINE_OVERRIDE(__cos_finite)
MACTRAMPOLINE_OVERRIDE(__cosf_finite)
MACTRAMPOLINE_OVERRIDE(__cosl_finite)
MACTRAMPOLINE_OVERRIDE(__tan_finite)
MACTRAMPOLINE_OVERRIDE(__tanf_finite)
MACTRAMPOLINE_OVERRIDE(__tanl_finite)
MACTRAMPOLINE_OVERRIDE(__log_finite)
MACTRAMPOLINE_OVERRIDE(__logf_finite)
MACTRAMPOLINE_OVERRIDE(__logl_finite)
MACTRAMPOLINE_OVERRIDE(__log2_finite)
MACTRAMPOLINE_OVERRIDE(__log2f_finite)
MACTRAMPOLINE_OVERRIDE(__log2l_finite)
MACTRAMPOLINE_OVERRIDE(__log10_finite)
MACTRAMPOLINE_OVERRIDE(__log10f_finite)
MACTRAMPOLINE_OVERRIDE(__log10l_finite)
MACTRAMPOLINE_OVERRIDE(__log1p_finite)
MACTRAMPOLINE_OVERRIDE(__log1pf_finite)
MACTRAMPOLINE_OVERRIDE(__log1pl_finite)
MACTRAMPOLINE_OVERRIDE(__asin_finite)
MACTRAMPOLINE_OVERRIDE(__asinf_finite)
MACTRAMPOLINE_OVERRIDE(__asinl_finite)
MACTRAMPOLINE_OVERRIDE(__acos_finite)
MACTRAMPOLINE_OVERRIDE(__acosf_finite)
MACTRAMPOLINE_OVERRIDE(__acosl_finite)
MACTRAMPOLINE_OVERRIDE(__atan_finite)
MACTRAMPOLINE_OVERRIDE(__atanf_finite)
MACTRAMPOLINE_OVERRIDE(__atanl_finite)
MACTRAMPOLINE_OVERRIDE(__sinh_finite)
MACTRAMPOLINE_OVERRIDE(__sinhf_finite)
MACTRAMPOLINE_OVERRIDE(__sinhl_finite)
MACTRAMPOLINE_OVERRIDE(__cosh_finite)
MACTRAMPOLINE_OVERRIDE(__coshf_finite)
MACTRAMPOLINE_OVERRIDE(__coshl_finite)
MACTRAMPOLINE_OVERRIDE(__tanh_finite)
MACTRAMPOLINE_OVERRIDE(__tanhf_finite)
MACTRAMPOLINE_OVERRIDE(__tanhl_finite)
MACTRAMPOLINE_OVERRIDE(__exp_finite)
MACTRAMPOLINE_OVERRIDE(__expf_finite)
MACTRAMPOLINE_OVERRIDE(__expl_finite)
MACTRAMPOLINE_OVERRIDE(__exp2_finite)
MACTRAMPOLINE_OVERRIDE(__exp2f_finite)
MACTRAMPOLINE_OVERRIDE(__exp2l_finite)
MACTRAMPOLINE_OVERRIDE(__expm1_finite)
MACTRAMPOLINE_OVERRIDE(__expm1f_finite)
MACTRAMPOLINE_OVERRIDE(__expm1l_finite)
MACTRAMPOLINE_OVERRIDE(__atan2_finite)
MACTRAMPOLINE_OVERRIDE(__atan2f_finite)
MACTRAMPOLINE_OVERRIDE(__atan2l_finite)
MACTRAMPOLINE_OVERRIDE(__pow_finite)
MACTRAMPOLINE_OVERRIDE(__powf_finite)
MACTRAMPOLINE_OVERRIDE(__powl_finite)
MACTRAMPOLINE_OVERRIDE(isnanl)
MACTRAMPOLINE_OVERRIDE(isnanf)
MACTRAMPOLINE_OVERRIDE(isnand)
MACTRAMPOLINE_OVERRIDE(__isnanl)
MACTRAMPOLINE_OVERRIDE(__isnanf)
MACTRAMPOLINE_OVERRIDE(__isnand)
MACTRAMPOLINE_OVERRIDE(accept)
MACTRAMPOLINE_OVERRIDE(bind)
MACTRAMPOLINE_OVERRIDE(connect)
MACTRAMPOLINE_OVERRIDE(getpeername)
MACTRAMPOLINE_OVERRIDE(getsockname)
MACTRAMPOLINE_OVERRIDE(getnameinfo)
MACTRAMPOLINE_OVERRIDE(inet_ntop)
MACTRAMPOLINE_OVERRIDE(inet_pton)
MACTRAMPOLINE_OVERRIDE(freeaddrinfo)
MACTRAMPOLINE_OVERRIDE(gai_strerror)
MACTRAMPOLINE_OVERRIDE(getaddrinfo)
MACTRAMPOLINE_OVERRIDE(setsockopt)
MACTRAMPOLINE_OVERRIDE(getsockopt)
MACTRAMPOLINE_OVERRIDE(recv)
MACTRAMPOLINE_OVERRIDE(recvfrom)
MACTRAMPOLINE_OVERRIDE(send)
MACTRAMPOLINE_OVERRIDE(sendto)
MACTRAMPOLINE(int,getifaddrs,(struct ifaddrs **a),(a),return)
MACTRAMPOLINE(void,freeifaddrs,(struct ifaddrs *a),(a),)
MACTRAMPOLINE(unsigned int,if_nametoindex,(const char *a),(a),return)
MACTRAMPOLINE(char *,if_indextoname,(unsigned int a, char *b),(a,b),return)
MACTRAMPOLINE(struct if_nameindex *,if_nameindex,(void),(),return)
MACTRAMPOLINE(void,if_freenameindex,(struct if_nameindex *a),(a),)

MACTRAMPOLINE_OVERRIDE(fcvt_r)

// !!! FIXME: mode_t is 2 bytes on Mac OS X, but 4 on Linux.
//MACTRAMPOLINE(DBM*,dbm_open,(const char *a, int b, mode_t c),(a,b,c),return)
//MACTRAMPOLINE(int,posix_spawn_file_actions_addopen,(posix_spawn_file_actions_t *a, int b, const char  *c, int d, mode_t e),(a,b,c,d,e),return)

// Believe it or not, va_list matches between Linux and Mac OS X.
//  (a void* on x86, an identical gcc-specific struct on amd64)
MACTRAMPOLINE(int,vfwprintf,(FILE *a, const wchar_t *b, va_list c),(a,b,c),return)
MACTRAMPOLINE(int,vfwscanf,(FILE *a, const wchar_t *b, va_list c),(a,b,c),return)
MACTRAMPOLINE(int,vwprintf,(const wchar_t *a, va_list b),(a,b),return)
MACTRAMPOLINE(int,vwscanf,(const wchar_t *a, va_list b),(a,b),return)
MACTRAMPOLINE(int,vswprintf,(wchar_t *a, size_t b, const wchar_t *c, va_list d),(a,b,c,d),return)
MACTRAMPOLINE(int,vswscanf,(const wchar_t *a, const wchar_t *b, va_list c),(a,b,c),return)
MACTRAMPOLINE(int,vfprintf,(FILE *a, const char *b, va_list c),(a,b,c),return)
MACTRAMPOLINE(int,vfscanf,(FILE *a, const char *b, va_list c),(a,b,c),return)
MACTRAMPOLINE(int,vprintf,(const char *a, va_list b),(a,b),return)
MACTRAMPOLINE(int,vscanf,(const char *a, va_list b),(a,b),return)
MACTRAMPOLINE(int,vsnprintf,(char *a, size_t b, const char *c, va_list d),(a,b,c,d),return)
MACTRAMPOLINE(int,vsprintf,(char *a, const char *b, va_list c),(a,b,c),return)
MACTRAMPOLINE(int,vsscanf,(const char *a, const char *b, va_list c),(a,b,c),return)

// !!! FIXME: varargs we need to explicitly handle.
//MACTRAMPOLINE(int,execl,(const char *a, const char *b, ... c),(a,b,c),return)
//MACTRAMPOLINE(int,execle,(const char *a, const char *b, ... c),(a,b,c),return)
//MACTRAMPOLINE(int,execlp,(const char *a, const char *b, ... c),(a,b,c),return)
MACTRAMPOLINE_OVERRIDE(syslog)
//MACTRAMPOLINE(long int,ulimit,(int a, ...),(a,b),return)
MACTRAMPOLINE_OVERRIDE(sem_open)

// !!! FIXME: these work differently on Mac OS X, and hopefully nothing ever uses them.
//MACTRAMPOLINE(int,brk,(void *a),(a),return)
//MACTRAMPOLINE(void*,sbrk,(intptr_t a),(a),return)

MACTRAMPOLINE_OVERRIDE(setmntent)
MACTRAMPOLINE_OVERRIDE(getmntent)
//MACTRAMPOLINE_OVERRIDE(addmntent)
MACTRAMPOLINE_OVERRIDE(endmntent)
//MACTRAMPOLINE_OVERRIDE(hasmntopt)

MACTRAMPOLINE_OVERRIDE(sigaction)
MACTRAMPOLINE_OVERRIDE(sigprocmask)

MACTRAMPOLINE_OVERRIDE(dl_iterate_phdr)


// Things that map directly, with just some stack-aligning macro glue.

//MACTRAMPOLINE(void,_Exit,(int a),(a),)
MACTRAMPOLINE(int,setjmp,(jmp_buf a),(a),return)
MACTRAMPOLINE(void,longjmp,(jmp_buf a, int b),(a,b),)
MACTRAMPOLINE(int,sigsetjmp,(sigjmp_buf a, int b),(a,b),return)
MACTRAMPOLINE(void,siglongjmp,(sigjmp_buf a, int b),(a,b),)
MACTRAMPOLINE(long,a64l,(const char *a),(a),return)
MACTRAMPOLINE(void,abort,(void),(),)
MACTRAMPOLINE(int,abs,(int a),(a),return)
MACTRAMPOLINE(int,atexit,(void(*a)(void)),(a),return)
MACTRAMPOLINE(double,atof,(const char *a),(a),return)
MACTRAMPOLINE(int,atoi,(const char *a),(a),return)
MACTRAMPOLINE(long int,atol,(const char *a),(a),return)
MACTRAMPOLINE(long long,atoll,(const char *a),(a),return)
MACTRAMPOLINE(void*,bsearch,(const void *a, const void *b, size_t c, size_t d, int(*e)(const void*, const void*)),(a,b,c,d,e),return)
MACTRAMPOLINE(void*,calloc,(size_t a, size_t b),(a,b),return)
MACTRAMPOLINE(div_t,div,(int a, int b),(a,b),return)
MACTRAMPOLINE(double,drand48,(void),(),return)
MACTRAMPOLINE(char*,ecvt,(double a, int b, int *c, int *d),(a,b,c,d),return)
MACTRAMPOLINE(double,erand48,(unsigned short int a[3]),(a),return)
MACTRAMPOLINE(void,exit,(int a),(a),)
MACTRAMPOLINE(char*,fcvt,(double a, int b, int *c, int *d),(a,b,c,d),return)
MACTRAMPOLINE(void,free,(void *a),(a),)
MACTRAMPOLINE(char*,gcvt,(double a, int b, char *c),(a,b,c),return)
MACTRAMPOLINE(char*,getenv,(const char *a),(a),return)
MACTRAMPOLINE(int,getsubopt,(char* *a, char *const *b, char* *c),(a,b,c),return)
MACTRAMPOLINE(int,grantpt,(int a),(a),return)
MACTRAMPOLINE(char*,initstate,(unsigned int a, char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(long int,jrand48,(unsigned short int a[3]),(a),return)
MACTRAMPOLINE(char*,l64a,(long a),(a),return)
MACTRAMPOLINE(long int,labs,(long int a),(a),return)
MACTRAMPOLINE(void,lcong48,(unsigned short int a[7]),(a),)
MACTRAMPOLINE(ldiv_t,ldiv,(long int a, long int b),(a,b),return)
MACTRAMPOLINE(long long,llabs,(long long a),(a),return)
MACTRAMPOLINE(lldiv_t,lldiv,(long long a, long long b),(a,b),return)
MACTRAMPOLINE(long int,lrand48,(void),(),return)
MACTRAMPOLINE(void*,malloc,(size_t a),(a),return)
MACTRAMPOLINE(int,mblen,(const char *a, size_t b),(a,b),return)
MACTRAMPOLINE(size_t,mbstowcs,(wchar_t *a, const char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,mbtowc,(wchar_t *a, const char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(char*,mktemp,(char *a),(a),return)
MACTRAMPOLINE(int,mkstemp,(char *a),(a),return)
MACTRAMPOLINE(long int,mrand48,(void),(),return)
MACTRAMPOLINE(long int,nrand48,(unsigned short int a[3]),(a),return)
MACTRAMPOLINE(int,posix_memalign,(void* *a, size_t b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,posix_openpt,(int a),(a),return)
MACTRAMPOLINE(char*,ptsname,(int a),(a),return)
MACTRAMPOLINE(int,putenv,(char *a),(a),return)
MACTRAMPOLINE(void,qsort,(void *a, size_t b, size_t c, int(*d)(const void *, const void *)),(a,b,c,d),)
MACTRAMPOLINE(int,rand,(void),(),return)
MACTRAMPOLINE(int,rand_r,(unsigned int *a),(a),return)
MACTRAMPOLINE(long,random,(void),(),return)
MACTRAMPOLINE(void*,realloc,(void *a, size_t b),(a,b),return)
MACTRAMPOLINE(char*,realpath,(const char *a, char *b),(a,b),return)
MACTRAMPOLINE(unsigned short int*,seed48,(unsigned short int a[3]),(a),return)
MACTRAMPOLINE(int,setenv,(const char *a, const char *b, int c),(a,b,c),return)
MACTRAMPOLINE(void,setkey,(const char *a),(a),)
MACTRAMPOLINE(char*,setstate,(char *a),(a),return)
MACTRAMPOLINE(void,srand,(unsigned int a),(a),)
MACTRAMPOLINE(void,srand48,(long int a),(a),)
MACTRAMPOLINE(void,srandom,(unsigned a),(a),)
MACTRAMPOLINE(double,strtod,(const char *a, char* *b),(a,b),return)
MACTRAMPOLINE(long int,strtol,(const char *a, char* *b, int c),(a,b,c),return)
MACTRAMPOLINE(unsigned long int,strtoul,(const char *a, char* *b, int c),(a,b,c),return)
MACTRAMPOLINE(int,system,(const char *a),(a),return)
MACTRAMPOLINE(int,ttyslot,(void),(),return)
MACTRAMPOLINE(int,unlockpt,(int a),(a),return)
MACTRAMPOLINE(int,unsetenv,(const char *a),(a),return)
MACTRAMPOLINE(void*,valloc,(size_t a),(a),return)
MACTRAMPOLINE(size_t,wcstombs,(char *a, const wchar_t *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,wctomb,(char *a, wchar_t b),(a,b),return)
MACTRAMPOLINE(wint_t,btowc,(int a),(a),return)
MACTRAMPOLINE(int,iswalnum,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswalpha,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswcntrl,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswdigit,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswgraph,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswlower,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswprint,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswpunct,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswspace,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswupper,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswxdigit,(wint_t a),(a),return)
MACTRAMPOLINE(int,iswctype,(wint_t a, wctype_t b),(a,b),return)
MACTRAMPOLINE(wint_t,fgetwc,(FILE *a),(a),return)
MACTRAMPOLINE(wchar_t*,fgetws,(wchar_t *a, int b, FILE *c),(a,b,c),return)
MACTRAMPOLINE(wint_t,fputwc,(wchar_t a, FILE *b),(a,b),return)
MACTRAMPOLINE(int,fputws,(const wchar_t *a, FILE *b),(a,b),return)
MACTRAMPOLINE(int,fwide,(FILE *a, int b),(a,b),return)
MACTRAMPOLINE(wint_t,getwc,(FILE *a),(a),return)
MACTRAMPOLINE(wint_t,getwchar,(void),(),return)
//MACTRAMPOLINE(int,mbsinit,(const mbstate_t *a),(a),return)
MACTRAMPOLINE(size_t,mbrlen,(const char *a, size_t b, mbstate_t *c),(a,b,c),return)
MACTRAMPOLINE(size_t,mbrtowc,(wchar_t *a, const char *b, size_t c, mbstate_t *d),(a,b,c,d),return)
MACTRAMPOLINE(size_t,mbsrtowcs,(wchar_t *a, const char* *b, size_t c, mbstate_t *d),(a,b,c,d),return)
MACTRAMPOLINE(wint_t,putwc,(wchar_t a, FILE *b),(a,b),return)
MACTRAMPOLINE(wint_t,putwchar,(wchar_t a),(a),return)
MACTRAMPOLINE(wint_t,towlower,(wint_t a),(a),return)
MACTRAMPOLINE(wint_t,towupper,(wint_t a),(a),return)
MACTRAMPOLINE(wint_t,ungetwc,(wint_t a, FILE *b),(a,b),return)
MACTRAMPOLINE(size_t,wcrtomb,(char *a, wchar_t b, mbstate_t *c),(a,b,c),return)
MACTRAMPOLINE(wchar_t*,wcscat,(wchar_t *a, const wchar_t *b),(a,b),return)
MACTRAMPOLINE(wchar_t*,wcschr,(const wchar_t *a, wchar_t b),(a,b),return)
MACTRAMPOLINE(int,wcscmp,(const wchar_t *a, const wchar_t *b),(a,b),return)
MACTRAMPOLINE(int,wcscoll,(const wchar_t *a, const wchar_t *b),(a,b),return)
MACTRAMPOLINE(wchar_t*,wcscpy,(wchar_t *a, const wchar_t *b),(a,b),return)
MACTRAMPOLINE(size_t,wcscspn,(const wchar_t *a, const wchar_t *b),(a,b),return)
MACTRAMPOLINE(size_t,wcsftime,(wchar_t *a, size_t b, const wchar_t *c, const struct tm *d),(a,b,c,d),return)
MACTRAMPOLINE(size_t,wcslen,(const wchar_t *a),(a),return)
MACTRAMPOLINE(wchar_t*,wcsncat,(wchar_t *a, const wchar_t *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,wcsncmp,(const wchar_t *a, const wchar_t *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(wchar_t*,wcsncpy,(wchar_t *a, const wchar_t *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(wchar_t*,wcspbrk,(const wchar_t *a, const wchar_t *b),(a,b),return)
MACTRAMPOLINE(wchar_t*,wcsrchr,(const wchar_t *a, wchar_t b),(a,b),return)
MACTRAMPOLINE(size_t,wcsrtombs,(char *a, const wchar_t* *b, size_t c, mbstate_t *d),(a,b,c,d),return)
MACTRAMPOLINE(size_t,wcsspn,(const wchar_t *a, const wchar_t *b),(a,b),return)
MACTRAMPOLINE(wchar_t*,wcsstr,(const wchar_t *a, const wchar_t *b),(a,b),return)
MACTRAMPOLINE(double,wcstod,(const wchar_t *a, wchar_t* *b),(a,b),return)
MACTRAMPOLINE(wchar_t*,wcstok,(wchar_t *a, const wchar_t *b, wchar_t* *c),(a,b,c),return)
MACTRAMPOLINE(long int,wcstol,(const wchar_t *a, wchar_t* *b, int c),(a,b,c),return)
MACTRAMPOLINE(unsigned long int,wcstoul,(const wchar_t *a, wchar_t* *b, int c),(a,b,c),return)
//MACTRAMPOLINE(wchar_t*,wcswcs,(const wchar_t *a, const wchar_t *b),(a,b),return)
MACTRAMPOLINE(int,wcswidth,(const wchar_t *a, size_t b),(a,b),return)
MACTRAMPOLINE(size_t,wcsxfrm,(wchar_t *a, const wchar_t *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,wctob,(wint_t a),(a),return)
MACTRAMPOLINE(wctype_t,wctype,(const char *a),(a),return)
MACTRAMPOLINE(int,wcwidth,(wchar_t a),(a),return)
MACTRAMPOLINE(wchar_t*,wmemchr,(const wchar_t *a, wchar_t b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,wmemcmp,(const wchar_t *a, const wchar_t *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(wchar_t*,wmemcpy,(wchar_t *a, const wchar_t *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(wchar_t*,wmemmove,(wchar_t *a, const wchar_t *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(wchar_t*,wmemset,(wchar_t *a, wchar_t b, size_t c),(a,b,c),return)
//MACTRAMPOLINE(int,regcomp,(regex_t *a, const char *b, int c),(a,b,c),return)
//MACTRAMPOLINE(int,regexec,(const regex_t *a, const char *b, size_t c, regmatch_t d[], int e),(a,b,c,d,e),return)
//MACTRAMPOLINE(size_t,regerror,(int a, const regex_t *b, char *c, size_t d),(a,b,c,d),return)
//MACTRAMPOLINE(void,regfree,(regex_t *a),(a),)
//MACTRAMPOLINE(int,sched_get_priority_max,(int a),(a),return)
//MACTRAMPOLINE(int,sched_get_priority_min,(int a),(a),return)
//MACTRAMPOLINE(int,sched_getparam,(pid_t a, struct sched_param *b),(a,b),return)
//MACTRAMPOLINE(int,sched_getscheduler,(pid_t a),(a),return)
//MACTRAMPOLINE(int,sched_rr_get_interval,(pid_t a, struct timespec *b),(a,b),return)
//MACTRAMPOLINE(int,sched_setparam,(pid_t a, const struct sched_param *b),(a,b),return)
//MACTRAMPOLINE(int,sched_setscheduler,(pid_t a, int b, const struct sched_param *c),(a,b,c),return)
MACTRAMPOLINE(int,sched_yield,(void),(),return)
MACTRAMPOLINE(int,utime,(const char *a, const struct utimbuf *b),(a,b),return)
MACTRAMPOLINE(iconv_t,iconv_open,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(size_t,iconv,(iconv_t a, char* *b, size_t *c, char* *d, size_t *e),(a,b,c,d,e),return)
MACTRAMPOLINE(int,iconv_close,(iconv_t a),(a),return)
MACTRAMPOLINE(int,isalnum,(int a),(a),return)
MACTRAMPOLINE(int,isalpha,(int a),(a),return)
MACTRAMPOLINE(int,iscntrl,(int a),(a),return)
MACTRAMPOLINE(int,isdigit,(int a),(a),return)
MACTRAMPOLINE(int,isgraph,(int a),(a),return)
MACTRAMPOLINE(int,islower,(int a),(a),return)
MACTRAMPOLINE(int,isprint,(int a),(a),return)
MACTRAMPOLINE(int,ispunct,(int a),(a),return)
MACTRAMPOLINE(int,isspace,(int a),(a),return)
MACTRAMPOLINE(int,isupper,(int a),(a),return)
MACTRAMPOLINE(int,isxdigit,(int a),(a),return)
MACTRAMPOLINE(int,tolower,(int a),(a),return)
MACTRAMPOLINE(int,toupper,(int a),(a),return)
MACTRAMPOLINE(int,isascii,(int a),(a),return)
MACTRAMPOLINE(int,toascii,(int a),(a),return)
//MACTRAMPOLINE(int,_toupper,(int a),(a),return)
//MACTRAMPOLINE(int,_tolower,(int a),(a),return)
MACTRAMPOLINE(void,bsd_signal,(int a, void(*b)(int)),(a,b),)
MACTRAMPOLINE(int,kill,(pid_t a, int b),(a,b),return)
MACTRAMPOLINE(int,killpg,(pid_t a, int b),(a,b),return)
MACTRAMPOLINE(int,pthread_kill,(pthread_t a, int b),(a,b),return)
MACTRAMPOLINE(int,raise,(int a),(a),return)
//MACTRAMPOLINE(int,sigaction,(int a, const struct sigaction *b, struct sigaction *c),(a,b,c),return)
// sigset_t is 32 bits on Mac OS X, but a massive array on Linux. Since it's opaque data, just use the first 32-bits of it.
MACTRAMPOLINE(int,sigaddset,(sigset_t *a, int b),(a,b),return)
//MACTRAMPOLINE(int,sigaltstack,(const stack_t *a, stack_t *b),(a,b),return)
MACTRAMPOLINE(int,sigdelset,(sigset_t *a, int b),(a,b),return)
MACTRAMPOLINE(int,sigemptyset,(sigset_t *a),(a),return)
MACTRAMPOLINE(int,sigfillset,(sigset_t *a),(a),return)
//MACTRAMPOLINE(int,sighold,(int a),(a),return)
//MACTRAMPOLINE(int,sigignore,(int a),(a),return)
//MACTRAMPOLINE(int,siginterrupt,(int a, int b),(a,b),return)
MACTRAMPOLINE(int,sigismember,(const sigset_t *a, int b),(a,b),return)
MACTRAMPOLINE(void,signal,(int a, void(*b)(int)),(a,b),)
//MACTRAMPOLINE(int,sigpause,(int a),(a),return)
MACTRAMPOLINE(int,sigpending,(sigset_t *a),(a),return)
//MACTRAMPOLINE(int,sigqueue,(pid_t a, int b, const union sigval c),(a,b,c),return)
//MACTRAMPOLINE(int,sigrelse,(int a),(a),return)
//MACTRAMPOLINE(void,sigset,(int a, void(*)(int)))(int b),(a,b),)
//MACTRAMPOLINE(int,sigstack,(struct sigstack *a, struct sigstack *b),(a,b),return)
MACTRAMPOLINE(int,sigsuspend,(const sigset_t *a),(a),return)
//MACTRAMPOLINE(int,sigtimedwait,(const sigset_t *a, siginfo_t *b, const struct timespec *c),(a,b,c),return)
MACTRAMPOLINE(int,sigwait,(const sigset_t *a, int *b),(a,b),return)
//MACTRAMPOLINE(int,sigwaitinfo,(const sigset_t *a, siginfo_t *b),(a,b),return)
//MACTRAMPOLINE(int,isastream,(int a),(a),return)
//MACTRAMPOLINE(int,getmsg,(int a, struct strbuf *b, struct strbuf *c, int *d),(a,b,c,d),return)
//MACTRAMPOLINE(int,getpmsg,(int a, struct strbuf *b, struct strbuf *c, int *d, int *e),(a,b,c,d,e),return)
//MACTRAMPOLINE(int,ioctl,(int a, int b, ... ),(a,b,c),return)
//MACTRAMPOLINE(int,putmsg,(int a, const struct strbuf *b, const struct strbuf *c, int d),(a,b,c,d),return)
//MACTRAMPOLINE(int,putpmsg,(int a, const struct strbuf *b, const struct strbuf *c, int d, int e),(a,b,c,d,e),return)
//MACTRAMPOLINE(int,fattach,(int a, const char *b),(a,b),return)
//MACTRAMPOLINE(int,fdetach,(const char *a),(a),return)
//MACTRAMPOLINE(int,fnmatch,(const char *a, const char *b, int c),(a,b,c),return)
//MACTRAMPOLINE(int,bcmp,(const void *a, const void *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(void,bcopy,(const void *a, void *b, size_t c),(a,b,c),)
MACTRAMPOLINE(void,bzero,(void *a, size_t b),(a,b),)
MACTRAMPOLINE(int,ffs,(int a),(a),return)
MACTRAMPOLINE(char*,index,(const char *a, int b),(a,b),return)
MACTRAMPOLINE(char*,rindex,(const char *a, int b),(a,b),return)
MACTRAMPOLINE(int,strcasecmp,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(int,strncasecmp,(const char *a, const char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(void,endhostent,(void),(),)
MACTRAMPOLINE(void,endnetent,(void),(),)
MACTRAMPOLINE(void,endprotoent,(void),(),)
MACTRAMPOLINE(void,endservent,(void),(),)
MACTRAMPOLINE(struct hostent*,gethostbyaddr,(const void *a, socklen_t b, int c),(a,b,c),return)
MACTRAMPOLINE(struct hostent*,gethostbyname,(const char *a),(a),return)
MACTRAMPOLINE(struct hostent*,gethostent,(void),(),return)
MACTRAMPOLINE(struct netent*,getnetbyaddr,(uint32_t a, int b),(a,b),return)
MACTRAMPOLINE(struct netent*,getnetbyname,(const char *a),(a),return)
MACTRAMPOLINE(struct netent*,getnetent,(void),(),return)
MACTRAMPOLINE(struct protoent*,getprotobyname,(const char *a),(a),return)
MACTRAMPOLINE(struct protoent*,getprotobynumber,(int a),(a),return)
MACTRAMPOLINE(struct protoent*,getprotoent,(void),(),return)
MACTRAMPOLINE(struct servent*,getservbyname,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(struct servent*,getservbyport,(int a, const char *b),(a,b),return)
MACTRAMPOLINE(struct servent*,getservent,(void),(),return)
MACTRAMPOLINE(void,sethostent,(int a),(a),)
MACTRAMPOLINE(void,setnetent,(int a),(a),)
MACTRAMPOLINE(void,setprotoent,(int a),(a),)
MACTRAMPOLINE(void,setservent,(int a),(a),)
//MACTRAMPOLINE(int,aio_cancel,(int a, struct aiocb *b),(a,b),return)
//MACTRAMPOLINE(int,aio_error,(const struct aiocb *a),(a),return)
//MACTRAMPOLINE(int,aio_fsync,(int a, struct aiocb *b),(a,b),return)
//MACTRAMPOLINE(int,aio_read,(struct aiocb *a),(a),return)
//MACTRAMPOLINE(ssize_t,aio_return,(struct aiocb *a),(a),return)
//MACTRAMPOLINE(int,aio_suspend,(const struct aiocb *const a[], int b, const struct timespec *c),(a,b,c),return)
//MACTRAMPOLINE(int,aio_write,(struct aiocb *a),(a),return)
//MACTRAMPOLINE(int,lio_listio,(int a, struct aiocb *const b[], int c, struct sigevent *d),(a,b,c,d),return)
MACTRAMPOLINE(wint_t,towctrans,(wint_t a, wctrans_t b),(a,b),return)
MACTRAMPOLINE(wctrans_t,wctrans,(const char *a),(a),return)
//MACTRAMPOLINE(int,posix_fadvise,(int a, off_t b, off_t c, int d),(a,b,c,d),return)
//MACTRAMPOLINE(int,posix_fallocate,(int a, off_t b, off_t c),(a,b,c),return)
//MACTRAMPOLINE(unsigned int,if_nametoindex,(const char *a),(a),return)
//MACTRAMPOLINE(char*,if_indextoname,(unsigned int a, char *b),(a,b),return)
//MACTRAMPOLINE(struct if_nameindex*,if_nameindex,(void),(),return)
//MACTRAMPOLINE(void,if_freenameindex,(struct if_nameindex *a),(a),)
MACTRAMPOLINE(int,access,(const char *a, int b),(a,b),return)
MACTRAMPOLINE(unsigned int,alarm,(unsigned int a),(a),return)
MACTRAMPOLINE(int,chdir,(const char *a),(a),return)
MACTRAMPOLINE(int,chroot,(const char *a),(a),return)
MACTRAMPOLINE(int,chown,(const char *a, uid_t b, gid_t c),(a,b,c),return)
MACTRAMPOLINE(int,close,(int a),(a),return)
//MACTRAMPOLINE(size_t,confstr,(int a, char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(char*,crypt,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(char*,ctermid,(char *a),(a),return)
//MACTRAMPOLINE(char*,cuserid,(char *a),(a),return)
MACTRAMPOLINE(int,dup,(int a),(a),return)
MACTRAMPOLINE(int,dup2,(int a, int b),(a,b),return)
MACTRAMPOLINE(void,encrypt,(char a[64], int b),(a,b),)
MACTRAMPOLINE(int,execv,(const char *a, char *const b[]),(a,b),return)
MACTRAMPOLINE(int,execve,(const char *a, char *const b[], char *const c[]),(a,b,c),return)
MACTRAMPOLINE(int,execvp,(const char *a, char *const b[]),(a,b),return)
MACTRAMPOLINE(void,_exit,(int a),(a),)
MACTRAMPOLINE(int,fchown,(int a, uid_t b, gid_t c),(a,b,c),return)
MACTRAMPOLINE(int,fchdir,(int a),(a),return)
//MACTRAMPOLINE(int,fdatasync,(int a),(a),return)
MACTRAMPOLINE(pid_t,fork,(void),(),return)
//MACTRAMPOLINE(long int,fpathconf,(int a, int b),(a,b),return)
MACTRAMPOLINE(int,fsync,(int a),(a),return)
MACTRAMPOLINE(char*,getcwd,(char *a, size_t b),(a,b),return)
//MACTRAMPOLINE(int,getdtablesize,(void),(),return)
MACTRAMPOLINE(gid_t,getegid,(void),(),return)
MACTRAMPOLINE(uid_t,geteuid,(void),(),return)
MACTRAMPOLINE(gid_t,getgid,(void),(),return)
//MACTRAMPOLINE(int,getgroups,(int a, gid_t b[]),(a,b),return)
MACTRAMPOLINE(long,gethostid,(void),(),return)
MACTRAMPOLINE(int,gethostname,(char *a, size_t b),(a,b),return)
MACTRAMPOLINE(int,sethostname,(const char *a, size_t b),(a,b),return)
MACTRAMPOLINE(int,getdomainname,(char *a, size_t b),(a,b),return)
MACTRAMPOLINE(int,setdomainname,(const char *a, size_t b),(a,b),return)
MACTRAMPOLINE(char*,getlogin,(void),(),return)
MACTRAMPOLINE(int,getlogin_r,(char *a, size_t b),(a,b),return)
MACTRAMPOLINE(int,getopt,(int a, char  *const *b, const char *c),(a,b,c),return)
MACTRAMPOLINE(int,getopt_long,(int a, char * const *b, const char *c, const struct option *d, int *e),(a,b,c,d,e),return)
MACTRAMPOLINE(int,getopt_long_only,(int a, char * const *b, const char *c, const struct option *d, int *e),(a,b,c,d,e),return)
MACTRAMPOLINE(int,getpagesize,(void),(),return)
MACTRAMPOLINE(char*,getpass,(const char *a),(a),return)
MACTRAMPOLINE(pid_t,getpgid,(pid_t a),(a),return)
MACTRAMPOLINE(pid_t,getpgrp,(void),(),return)
MACTRAMPOLINE(pid_t,getpid,(void),(),return)
MACTRAMPOLINE(pid_t,getppid,(void),(),return)
MACTRAMPOLINE(pid_t,getsid,(pid_t a),(a),return)
MACTRAMPOLINE(uid_t,getuid,(void),(),return)
MACTRAMPOLINE(char*,getwd,(char *a),(a),return)
MACTRAMPOLINE(int,isatty,(int a),(a),return)
MACTRAMPOLINE(int,lchown,(const char *a, uid_t b, gid_t c),(a,b,c),return)
MACTRAMPOLINE(int,link,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(int,nice,(int a),(a),return)
//MACTRAMPOLINE(long int,pathconf,(const char *a, int b),(a,b),return)
MACTRAMPOLINE(int,pause,(void),(),return)
MACTRAMPOLINE(int,pipe,(int a[2]),(a),return)
MACTRAMPOLINE(ssize_t,read,(int a, void *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(ssize_t,readlink,(const char *a, char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,rmdir,(const char *a),(a),return)
//MACTRAMPOLINE(void*,sbrk,(intptr_t a),(a),return)
MACTRAMPOLINE(int,setegid,(gid_t a),(a),return)
MACTRAMPOLINE(int,seteuid,(uid_t a),(a),return)
MACTRAMPOLINE(int,setgid,(gid_t a),(a),return)
MACTRAMPOLINE(int,setpgid,(pid_t a, pid_t b),(a,b),return)
MACTRAMPOLINE(pid_t,setpgrp,(void),(),return)
MACTRAMPOLINE(int,setregid,(gid_t a, gid_t b),(a,b),return)
MACTRAMPOLINE(int,setreuid,(uid_t a, uid_t b),(a,b),return)
MACTRAMPOLINE(pid_t,setsid,(void),(),return)
MACTRAMPOLINE(int,setuid,(uid_t a),(a),return)
MACTRAMPOLINE(unsigned int,sleep,(unsigned int a),(a),return)
MACTRAMPOLINE(void,swab,(const void *a, void *b, ssize_t c),(a,b,c),)
MACTRAMPOLINE(int,symlink,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(void,sync,(void),(),)
//MACTRAMPOLINE(long int,sysconf,(int a),(a),return)
MACTRAMPOLINE(pid_t,tcgetpgrp,(int a),(a),return)
MACTRAMPOLINE(int,tcsetpgrp,(int a, pid_t b),(a,b),return)
MACTRAMPOLINE(char*,ttyname,(int a),(a),return)
MACTRAMPOLINE(int,ttyname_r,(int a, char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(useconds_t,ualarm,(useconds_t a, useconds_t b),(a,b),return)
MACTRAMPOLINE(int,unlink,(const char *a),(a),return)
MACTRAMPOLINE(int,usleep,(useconds_t a),(a),return)
MACTRAMPOLINE(pid_t,vfork,(void),(),return)
MACTRAMPOLINE(ssize_t,write,(int a, const void *b, size_t c),(a,b,c),return)
//MACTRAMPOLINE(int,mq_close,(mqd_t a),(a),return)
//MACTRAMPOLINE(int,mq_getattr,(mqd_t a, struct mq_attr *b),(a,b),return)
//MACTRAMPOLINE(int,mq_notify,(mqd_t a, const struct sigevent *b),(a,b),return)
//MACTRAMPOLINE(mqd_t,mq_open,(const char *a, int b, ...),(a,b,c),return)
//MACTRAMPOLINE(ssize_t,mq_receive,(mqd_t a, char *b, size_t c, unsigned int *d),(a,b,c,d),return)
//MACTRAMPOLINE(int,mq_send,(mqd_t a, const char *b, size_t c, unsigned int d),(a,b,c,d),return)
//MACTRAMPOLINE(int,mq_setattr,(mqd_t a, const struct mq_attr *b, struct mq_attr *c),(a,b,c),return)
//MACTRAMPOLINE(int,mq_unlink,(const char *a),(a),return)
MACTRAMPOLINE(double,acos,(double a),(a),return)
MACTRAMPOLINE(double,asin,(double a),(a),return)
MACTRAMPOLINE(double,atan,(double a),(a),return)
MACTRAMPOLINE(double,atan2,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,ceil,(double a),(a),return)
MACTRAMPOLINE(double,copysign,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,cos,(double a),(a),return)
MACTRAMPOLINE(double,cosh,(double a),(a),return)
MACTRAMPOLINE(double,exp,(double a),(a),return)
MACTRAMPOLINE(double,exp2,(double a),(a),return)
MACTRAMPOLINE(double,fabs,(double a),(a),return)
MACTRAMPOLINE(double,floor,(double a),(a),return)
MACTRAMPOLINE(double,fmod,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,frexp,(double a, int *b),(a,b),return)
MACTRAMPOLINE(double,ldexp,(double a, int b),(a,b),return)
MACTRAMPOLINE(double,log,(double a),(a),return)
MACTRAMPOLINE(double,log10,(double a),(a),return)
MACTRAMPOLINE(double,log2,(double a),(a),return)
MACTRAMPOLINE(double,modf,(double a, double *b),(a,b),return)
MACTRAMPOLINE(double,pow,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,sin,(double a),(a),return)
MACTRAMPOLINE(double,sinh,(double a),(a),return)
MACTRAMPOLINE(double,sqrt,(double a),(a),return)
MACTRAMPOLINE(double,tan,(double a),(a),return)
MACTRAMPOLINE(double,tanh,(double a),(a),return)
MACTRAMPOLINE(double,erf,(double a),(a),return)
MACTRAMPOLINE(double,erfc,(double a),(a),return)
MACTRAMPOLINE(double,gamma,(double a),(a),return)
MACTRAMPOLINE(double,hypot,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,j0,(double a),(a),return)
MACTRAMPOLINE(double,j1,(double a),(a),return)
MACTRAMPOLINE(double,jn,(int a, double b),(a,b),return)
MACTRAMPOLINE(double,lgamma,(double a),(a),return)
MACTRAMPOLINE(double,tgamma,(double a),(a),return)
MACTRAMPOLINE(double,y0,(double a),(a),return)
MACTRAMPOLINE(double,y1,(double a),(a),return)
MACTRAMPOLINE(double,yn,(int a, double b),(a,b),return)
MACTRAMPOLINE(int,isnan,(double a),(a),return)
MACTRAMPOLINE(int,isinf,(double a),(a),return)
MACTRAMPOLINE(int,isfinite,(double a),(a),return)
MACTRAMPOLINE(int,finite,(double a),(a),return)
MACTRAMPOLINE(double,acosh,(double a),(a),return)
MACTRAMPOLINE(double,asinh,(double a),(a),return)
MACTRAMPOLINE(double,atanh,(double a),(a),return)
MACTRAMPOLINE(double,cbrt,(double a),(a),return)
MACTRAMPOLINE(double,expm1,(double a),(a),return)
MACTRAMPOLINE(int,ilogb,(double a),(a),return)
MACTRAMPOLINE(double,log1p,(double a),(a),return)
MACTRAMPOLINE(double,logb,(double a),(a),return)
MACTRAMPOLINE(double,nextafter,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,nexttoward,(double a, long double b),(a,b),return)
MACTRAMPOLINE(double,nearbyint,(double a),(a),return)
MACTRAMPOLINE(double,remainder,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,rint,(double a),(a),return)
MACTRAMPOLINE(double,round,(double a),(a),return)
MACTRAMPOLINE(double,trunc,(double a),(a),return)
MACTRAMPOLINE(long,lrint,(double a),(a),return)
MACTRAMPOLINE(long long,llrint,(double a),(a),return)
MACTRAMPOLINE(long,lround,(double a),(a),return)
MACTRAMPOLINE(long long,llround,(double a),(a),return)
MACTRAMPOLINE(double,remquo,(double a, double b, int *c),(a,b,c),return)
MACTRAMPOLINE(double,scalb,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,scalbn,(double a, int b),(a,b),return)
MACTRAMPOLINE(double,scalbln,(double a, long b),(a,b),return)
MACTRAMPOLINE(double,fdim,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,fmax,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,fmin,(double a, double b),(a,b),return)
MACTRAMPOLINE(double,fma,(double a, double b, double c),(a,b,c),return)
MACTRAMPOLINE(double,nan,(const char *a),(a),return)
MACTRAMPOLINE(float,acosf,(float a),(a),return)
MACTRAMPOLINE(float,asinf,(float a),(a),return)
MACTRAMPOLINE(float,atanf,(float a),(a),return)
MACTRAMPOLINE(float,atan2f,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,ceilf,(float a),(a),return)
MACTRAMPOLINE(float,copysignf,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,cosf,(float a),(a),return)
MACTRAMPOLINE(float,coshf,(float a),(a),return)
MACTRAMPOLINE(float,expf,(float a),(a),return)
MACTRAMPOLINE(float,exp2f,(float a),(a),return)
MACTRAMPOLINE(float,fabsf,(float a),(a),return)
MACTRAMPOLINE(float,floorf,(float a),(a),return)
MACTRAMPOLINE(float,fmodf,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,frexpf,(float a, int *b),(a,b),return)
MACTRAMPOLINE(float,ldexpf,(float a, int b),(a,b),return)
MACTRAMPOLINE(float,logf,(float a),(a),return)
MACTRAMPOLINE(float,log10f,(float a),(a),return)
MACTRAMPOLINE(float,log2f,(float a),(a),return)
MACTRAMPOLINE(float,modff,(float a, float *b),(a,b),return)
MACTRAMPOLINE(float,powf,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,sinf,(float a),(a),return)
MACTRAMPOLINE(float,sinhf,(float a),(a),return)
MACTRAMPOLINE(float,sqrtf,(float a),(a),return)
MACTRAMPOLINE(float,tanf,(float a),(a),return)
MACTRAMPOLINE(float,tanhf,(float a),(a),return)
MACTRAMPOLINE(float,erff,(float a),(a),return)
MACTRAMPOLINE(float,erfcf,(float a),(a),return)
//MACTRAMPOLINE(float,gammaf,(float a),(a),return)
MACTRAMPOLINE(float,hypotf,(float a, float b),(a,b),return)
//MACTRAMPOLINE(float,j0f,(float a),(a),return)
//MACTRAMPOLINE(float,j1f,(float a),(a),return)
//MACTRAMPOLINE(float,jnf,(int a, float b),(a,b),return)
MACTRAMPOLINE(float,lgammaf,(float a),(a),return)
MACTRAMPOLINE(float,tgammaf,(float a),(a),return)
//MACTRAMPOLINE(float,y0f,(float a),(a),return)
//MACTRAMPOLINE(float,y1f,(float a),(a),return)
//MACTRAMPOLINE(float,ynf,(int a, float b),(a,b),return)
MACTRAMPOLINE(float,acoshf,(float a),(a),return)
MACTRAMPOLINE(float,asinhf,(float a),(a),return)
MACTRAMPOLINE(float,atanhf,(float a),(a),return)
MACTRAMPOLINE(float,cbrtf,(float a),(a),return)
MACTRAMPOLINE(float,expm1f,(float a),(a),return)
MACTRAMPOLINE(int,ilogbf,(float a),(a),return)
MACTRAMPOLINE(float,log1pf,(float a),(a),return)
MACTRAMPOLINE(float,logbf,(float a),(a),return)
MACTRAMPOLINE(float,nextafterf,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,nexttowardf,(float a, long double b),(a,b),return)
MACTRAMPOLINE(float,nearbyintf,(float a),(a),return)
MACTRAMPOLINE(float,remainderf,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,rintf,(float a),(a),return)
MACTRAMPOLINE(float,roundf,(float a),(a),return)
MACTRAMPOLINE(float,truncf,(float a),(a),return)
MACTRAMPOLINE(long,lrintf,(float a),(a),return)
MACTRAMPOLINE(long long,llrintf,(float a),(a),return)
MACTRAMPOLINE(long,lroundf,(float a),(a),return)
MACTRAMPOLINE(long long,llroundf,(float a),(a),return)
MACTRAMPOLINE(float,remquof,(float a, float b, int *c),(a,b,c),return)
//MACTRAMPOLINE(float,scalbf,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,scalbnf,(float a, int b),(a,b),return)
MACTRAMPOLINE(float,scalblnf,(float a, long b),(a,b),return)
MACTRAMPOLINE(float,fdimf,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,fmaxf,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,fminf,(float a, float b),(a,b),return)
MACTRAMPOLINE(float,fmaf,(float a, float b, float c),(a,b,c),return)
MACTRAMPOLINE(float,nanf,(const char *a),(a),return)
MACTRAMPOLINE(long double,acosl,(long double a),(a),return)
MACTRAMPOLINE(long double,asinl,(long double a),(a),return)
MACTRAMPOLINE(long double,atanl,(long double a),(a),return)
MACTRAMPOLINE(long double,atan2l,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,ceill,(long double a),(a),return)
MACTRAMPOLINE(long double,copysignl,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,cosl,(long double a),(a),return)
MACTRAMPOLINE(long double,coshl,(long double a),(a),return)
MACTRAMPOLINE(long double,expl,(long double a),(a),return)
MACTRAMPOLINE(long double,exp2l,(long double a),(a),return)
MACTRAMPOLINE(long double,fabsl,(long double a),(a),return)
MACTRAMPOLINE(long double,floorl,(long double a),(a),return)
MACTRAMPOLINE(long double,fmodl,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,frexpl,(long double a, int *b),(a,b),return)
MACTRAMPOLINE(long double,ldexpl,(long double a, int b),(a,b),return)
MACTRAMPOLINE(long double,logl,(long double a),(a),return)
MACTRAMPOLINE(long double,log10l,(long double a),(a),return)
MACTRAMPOLINE(long double,log2l,(long double a),(a),return)
MACTRAMPOLINE(long double,modfl,(long double a, long double *b),(a,b),return)
MACTRAMPOLINE(long double,powl,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,sinl,(long double a),(a),return)
MACTRAMPOLINE(long double,sinhl,(long double a),(a),return)
MACTRAMPOLINE(long double,sqrtl,(long double a),(a),return)
MACTRAMPOLINE(long double,tanl,(long double a),(a),return)
MACTRAMPOLINE(long double,tanhl,(long double a),(a),return)
MACTRAMPOLINE(long double,erfl,(long double a),(a),return)
MACTRAMPOLINE(long double,erfcl,(long double a),(a),return)
//MACTRAMPOLINE(long double,gammal,(long double a),(a),return)
MACTRAMPOLINE(long double,hypotl,(long double a, long double b),(a,b),return)
//MACTRAMPOLINE(long double,j0l,(long double a),(a),return)
//MACTRAMPOLINE(long double,j1l,(long double a),(a),return)
//MACTRAMPOLINE(long double,jnl,(int a, long double b),(a,b),return)
MACTRAMPOLINE(long double,lgammal,(long double a),(a),return)
MACTRAMPOLINE(long double,tgammal,(long double a),(a),return)
//MACTRAMPOLINE(long double,y0l,(long double a),(a),return)
//MACTRAMPOLINE(long double,y1l,(long double a),(a),return)
//MACTRAMPOLINE(long double,ynl,(int a, long double b),(a,b),return)
MACTRAMPOLINE(long double,acoshl,(long double a),(a),return)
MACTRAMPOLINE(long double,asinhl,(long double a),(a),return)
MACTRAMPOLINE(long double,atanhl,(long double a),(a),return)
MACTRAMPOLINE(long double,cbrtl,(long double a),(a),return)
MACTRAMPOLINE(long double,expm1l,(long double a),(a),return)
MACTRAMPOLINE(int,ilogbl,(long double a),(a),return)
MACTRAMPOLINE(long double,log1pl,(long double a),(a),return)
MACTRAMPOLINE(long double,logbl,(long double a),(a),return)
MACTRAMPOLINE(long double,nextafterl,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,nexttowardl,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,nearbyintl,(long double a),(a),return)
MACTRAMPOLINE(long double,remainderl,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,rintl,(long double a),(a),return)
MACTRAMPOLINE(long double,roundl,(long double a),(a),return)
MACTRAMPOLINE(long double,truncl,(long double a),(a),return)
MACTRAMPOLINE(long,lrintl,(long double a),(a),return)
MACTRAMPOLINE(long long,llrintl,(long double a),(a),return)
MACTRAMPOLINE(long,lroundl,(long double a),(a),return)
MACTRAMPOLINE(long long,llroundl,(long double a),(a),return)
MACTRAMPOLINE(long double,remquol,(long double a, long double b, int *c),(a,b,c),return)
//MACTRAMPOLINE(long double,scalbl,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,scalbnl,(long double a, int b),(a,b),return)
MACTRAMPOLINE(long double,scalblnl,(long double a, long b),(a,b),return)
MACTRAMPOLINE(long double,fdiml,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,fmaxl,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,fminl,(long double a, long double b),(a,b),return)
MACTRAMPOLINE(long double,fmal,(long double a, long double b, long double c),(a,b,c),return)
MACTRAMPOLINE(long double,nanl,(const char *a),(a),return)
MACTRAMPOLINE(double,cabs,(double complex a),(a),return)
MACTRAMPOLINE(double complex,cacos,(double complex a),(a),return)
MACTRAMPOLINE(double complex,cacosh,(double complex a),(a),return)
MACTRAMPOLINE(double,carg,(double complex a),(a),return)
MACTRAMPOLINE(double complex,casin,(double complex a),(a),return)
MACTRAMPOLINE(double complex,casinh,(double complex a),(a),return)
MACTRAMPOLINE(double complex,catan,(double complex a),(a),return)
MACTRAMPOLINE(double complex,catanh,(double complex a),(a),return)
MACTRAMPOLINE(double complex,ccos,(double complex a),(a),return)
MACTRAMPOLINE(double complex,ccosh,(double complex a),(a),return)
MACTRAMPOLINE(double complex,cexp,(double complex a),(a),return)
MACTRAMPOLINE(double,cimag,(double complex a),(a),return)
MACTRAMPOLINE(double complex,clog,(double complex a),(a),return)
MACTRAMPOLINE(double complex,conj,(double complex a),(a),return)
MACTRAMPOLINE(double complex,cpow,(double complex a, double complex b),(a,b),return)
MACTRAMPOLINE(double complex,cproj,(double complex a),(a),return)
MACTRAMPOLINE(double,creal,(double complex a),(a),return)
MACTRAMPOLINE(double complex,csin,(double complex a),(a),return)
MACTRAMPOLINE(double complex,csinh,(double complex a),(a),return)
MACTRAMPOLINE(double complex,csqrt,(double complex a),(a),return)
MACTRAMPOLINE(double complex,ctan,(double complex a),(a),return)
MACTRAMPOLINE(double complex,ctanh,(double complex a),(a),return)
MACTRAMPOLINE(float,cabsf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,cacosf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,cacoshf,(float complex a),(a),return)
MACTRAMPOLINE(float,cargf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,casinf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,casinhf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,catanf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,catanhf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,ccosf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,ccoshf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,cexpf,(float complex a),(a),return)
MACTRAMPOLINE(float,cimagf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,clogf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,conjf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,cpowf,(float complex a, float complex b),(a,b),return)
MACTRAMPOLINE(float complex,cprojf,(float complex a),(a),return)
MACTRAMPOLINE(float,crealf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,csinf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,csinhf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,csqrtf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,ctanf,(float complex a),(a),return)
MACTRAMPOLINE(float complex,ctanhf,(float complex a),(a),return)
MACTRAMPOLINE(long double,cabsl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,cacosl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,cacoshl,(long double complex a),(a),return)
MACTRAMPOLINE(long double,cargl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,casinhl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,casinl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,catanhl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,catanl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,ccoshl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,ccosl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,cexpl,(long double complex a),(a),return)
MACTRAMPOLINE(long double,cimagl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,clogl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,conjl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,cpowl,(long double complex a, long double complex b),(a,b),return)
MACTRAMPOLINE(long double complex,cprojl,(long double complex a),(a),return)
MACTRAMPOLINE(long double,creall,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,csinhl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,csinl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,csqrtl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,ctanhl,(long double complex a),(a),return)
MACTRAMPOLINE(long double complex,ctanl,(long double complex a),(a),return)
//MACTRAMPOLINE(char*,nl_langinfo,(nl_item a),(a),return)
//MACTRAMPOLINE(intmax_t,imaxabs,(intmax_t a),(a),return)
//MACTRAMPOLINE(imaxdiv_t,imaxdiv,(intmax_t a, intmax_t b),(a,b),return)
//MACTRAMPOLINE(intmax_t,strtoimax,(const char *a, char* *b, int c),(a,b,c),return)
//MACTRAMPOLINE(uintmax_t,strtoumax,(const char *a, char* *b, int c),(a,b,c),return)
//MACTRAMPOLINE(intmax_t,wcstoimax,(const wchar_t *a, wchar_t* *b, int c),(a,b,c),return)
//MACTRAMPOLINE(uintmax_t,wcstoumax,(const wchar_t *a, wchar_t* *b, int c),(a,b,c),return)
//MACTRAMPOLINE(int,poll,(struct pollfd a[], nfds_t b, int c),(a,b,c),return)
MACTRAMPOLINE(char*,asctime,(const struct tm *a),(a),return)
MACTRAMPOLINE(char*,asctime_r,(const struct tm *a, char *b),(a,b),return)
MACTRAMPOLINE(clock_t,clock,(void),(),return)
//MACTRAMPOLINE(int,clock_getcpuclockid,(pid_t a, clockid_t *b),(a,b),return)
//MACTRAMPOLINE(int,clock_getres,(clockid_t a, struct timespec *b),(a,b),return)
//MACTRAMPOLINE(int,clock_gettime,(clockid_t a, struct timespec *b),(a,b),return)
//MACTRAMPOLINE(int,clock_nanosleep,(clockid_t a, int b, const struct timespec *c, struct timespec *d),(a,b,c,d),return)
//MACTRAMPOLINE(int,clock_settime,(clockid_t a, const struct timespec *b),(a,b),return)
MACTRAMPOLINE(char*,ctime,(const time_t *a),(a),return)
MACTRAMPOLINE(char*,ctime_r,(const time_t *a, char *b),(a,b),return)
MACTRAMPOLINE(double,difftime,(time_t a, time_t b),(a,b),return)
MACTRAMPOLINE(struct tm*,getdate,(const char *a),(a),return)
MACTRAMPOLINE(struct tm*,gmtime,(const time_t *a),(a),return)
MACTRAMPOLINE(struct tm*,gmtime_r,(const time_t *a, struct tm *b),(a,b),return)
MACTRAMPOLINE(struct tm*,localtime,(const time_t *a),(a),return)
MACTRAMPOLINE(struct tm*,localtime_r,(const time_t *a, struct tm *b),(a,b),return)
MACTRAMPOLINE(time_t,mktime,(struct tm *a),(a),return)
MACTRAMPOLINE(int,nanosleep,(const struct timespec *a, struct timespec *b),(a,b),return)
MACTRAMPOLINE(size_t,strftime,(char *a, size_t b, const char *c, const struct tm *d),(a,b,c,d),return)
MACTRAMPOLINE(char*,strptime,(const char *a, const char *b, struct tm *c),(a,b,c),return)
MACTRAMPOLINE(time_t,time,(time_t *a),(a),return)
//MACTRAMPOLINE(int,timer_create,(clockid_t a, struct sigevent *b, timer_t *c),(a,b,c),return)
//MACTRAMPOLINE(int,timer_delete,(timer_t a),(a),return)
//MACTRAMPOLINE(int,timer_gettime,(timer_t a, struct itimerspec *b),(a,b),return)
//MACTRAMPOLINE(int,timer_getoverrun,(timer_t a),(a),return)
//MACTRAMPOLINE(int,timer_settime,(timer_t a, int b, const struct itimerspec *c, struct itimerspec *d),(a,b,c,d),return)
MACTRAMPOLINE(void,tzset,(void),(),)
//MACTRAMPOLINE(ssize_t,strfmon,(char *a, size_t b, const char *c, ...),(a,b,c,d),return)
//MACTRAMPOLINE(void,endutxent,(void),(),)
//MACTRAMPOLINE(struct utmpx*,getutxent,(void),(),return)
//MACTRAMPOLINE(struct utmpx*,getutxid,(const struct utmpx *a),(a),return)
//MACTRAMPOLINE(struct utmpx*,getutxline,(const struct utmpx *a),(a),return)
//MACTRAMPOLINE(struct utmpx*,pututxline,(const struct utmpx *a),(a),return)
//MACTRAMPOLINE(void,setutxent,(void),(),)
//MACTRAMPOLINE(int,hcreate,(size_t a),(a),return)
//MACTRAMPOLINE(void,hdestroy,(void),(),)
//MACTRAMPOLINE(ENTRY*,hsearch,(ENTRY a, ACTION b),(a,b),return)
//MACTRAMPOLINE(void,insque,(void *a, void *b),(a,b),)
//MACTRAMPOLINE(void*,lfind,(const void *a, const void *b, size_t *c, size_t d, int (*)(const void *e, const void*) f),(a,b,c,d,e,f),return)
//MACTRAMPOLINE(void*,lsearch,(const void *a, void *b, size_t *c, size_t d, int (*)(const void *e, const void*) f),(a,b,c,d,e,f),return)
//MACTRAMPOLINE(void,remque,(void *a),(a),)
//MACTRAMPOLINE(void*,tdelete,(const void *a, void* *b, int(*)(const void *c, const void*) d),(a,b,c,d),return)
//MACTRAMPOLINE(void*,tfind,(const void *a, void*const *b, int(*)(const void *c, const void*) d),(a,b,c,d),return)
//MACTRAMPOLINE(void*,tsearch,(const void *a, void* *b, int(*)(const void *c, const void*) d),(a,b,c,d),return)
//MACTRAMPOLINE(void,twalk,(const void *a, void (*) (const void *b, VISIT c, int) d),(a,b,c,d),)
//MACTRAMPOLINE(int,wordexp,(const char *a, wordexp_t *b, int c),(a,b,c),return)
//MACTRAMPOLINE(void,wordfree,(wordexp_t *a),(a),)
//MACTRAMPOLINE(int,ftw,(const char *a, int (*) (const char  *b, const struct stat *c, int) d, int e),(a,b,c,d,e),return)
//MACTRAMPOLINE(int,nftw,(const char *a, int (*) (const char  *b, const struct stat *c, int d, struct FTW *) e, int f, int g),(a,b,c,d,e,f,g),return)
MACTRAMPOLINE(char*,basename,(char *a),(a),return)
MACTRAMPOLINE(char*,dirname,(char *a),(a),return)
//MACTRAMPOLINE(int,fmtmsg,(long a, const char *b, int c, const char *d, const char *e, const char *f),(a,b,c,d,e,f),return)
//MACTRAMPOLINE(int,catclose,(nl_catd a),(a),return)
//MACTRAMPOLINE(char*,catgets,(nl_catd a, int b, int c, const char *d),(a,b,c,d),return)
//MACTRAMPOLINE(nl_catd,catopen,(const char *a, int b),(a,b),return)
MACTRAMPOLINE(void,closelog,(void),(),)
MACTRAMPOLINE(void,openlog,(const char *a, int b, int c),(a,b,c),)
MACTRAMPOLINE(int,setlogmask,(int a),(a),return)
MACTRAMPOLINE(void,endpwent,(void),(),)
MACTRAMPOLINE(void,setpwent,(void),(),)
MACTRAMPOLINE(int,sem_close,(sem_t *a),(a),return)
MACTRAMPOLINE(int,sem_destroy,(sem_t *a),(a),return)
MACTRAMPOLINE(int,sem_getvalue,(sem_t *a, int *b),(a,b),return)
MACTRAMPOLINE(int,sem_init,(sem_t *a, int b, unsigned int c),(a,b,c),return)
MACTRAMPOLINE(int,sem_post,(sem_t *a),(a),return)
//MACTRAMPOLINE(int,sem_timedwait,(sem_t *a, const struct timespec *b),(a,b),return)
MACTRAMPOLINE(int,sem_trywait,(sem_t *a),(a),return)
MACTRAMPOLINE(int,sem_unlink,(const char *a),(a),return)
MACTRAMPOLINE(int,sem_wait,(sem_t *a),(a),return)
MACTRAMPOLINE(uint32_t,htonl,(uint32_t a),(a),return)
MACTRAMPOLINE(uint16_t,htons,(uint16_t a),(a),return)
MACTRAMPOLINE(uint32_t,ntohl,(uint32_t a),(a),return)
MACTRAMPOLINE(uint16_t,ntohs,(uint16_t a),(a),return)
//MACTRAMPOLINE(speed_t,cfgetispeed,(const struct termios *a),(a),return)
//MACTRAMPOLINE(speed_t,cfgetospeed,(const struct termios *a),(a),return)
//MACTRAMPOLINE(int,cfsetispeed,(struct termios *a, speed_t b),(a,b),return)
//MACTRAMPOLINE(int,cfsetospeed,(struct termios *a, speed_t b),(a,b),return)
//MACTRAMPOLINE(int,tcdrain,(int a),(a),return)
//MACTRAMPOLINE(int,tcflow,(int a, int b),(a,b),return)
//MACTRAMPOLINE(int,tcflush,(int a, int b),(a,b),return)
//MACTRAMPOLINE(int,tcgetattr,(int a, struct termios *b),(a,b),return)
//MACTRAMPOLINE(pid_t,tcgetsid,(int a),(a),return)
//MACTRAMPOLINE(int,tcsendbreak,(int a, int b),(a,b),return)
//MACTRAMPOLINE(int,tcsetattr,(int a, int b, const struct termios *c),(a,b,c),return)
//MACTRAMPOLINE(int,getcontext,(ucontext_t *a),(a),return)
//MACTRAMPOLINE(int,setcontext,(const ucontext_t *a),(a),return)
//MACTRAMPOLINE(void,makecontext,(ucontext_t *a, void(*)(void) b, int c, ...),(a,b,c,d),)
//MACTRAMPOLINE(int,swapcontext,(ucontext_t *a, const ucontext_t *b),(a,b),return)
MACTRAMPOLINE(void*,memccpy,(void *a, const void *b, int c, size_t d),(a,b,c,d),return)
MACTRAMPOLINE(void*,memchr,(const void *a, int b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,memcmp,(const void *a, const void *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(void*,memcpy,(void *a, const void *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(void*,memmove,(void *a, const void *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(void*,memset,(void *a, int b, size_t c),(a,b,c),return)
MACTRAMPOLINE(char*,strcat,(char *a, const char *b),(a,b),return)
MACTRAMPOLINE(char*,strchr,(const char *a, int b),(a,b),return)
MACTRAMPOLINE(int,strcmp,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(int,strcoll,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(char*,strcpy,(char *a, const char *b),(a,b),return)
MACTRAMPOLINE(char*,stpcpy,(char *a, const char *b),(a,b),return)
MACTRAMPOLINE(size_t,strcspn,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(char*,strdup,(const char *a),(a),return)
MACTRAMPOLINE(char*,strerror,(int a),(a),return)
MACTRAMPOLINE(int,strerror_r,(int a, char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(size_t,strlen,(const char *a),(a),return)
MACTRAMPOLINE(size_t,strnlen,(const char *a,size_t b),(a,b),return)
MACTRAMPOLINE(char*,strncat,(char *a, const char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,strncmp,(const char *a, const char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(char*,strncpy,(char *a, const char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(char*,stpncpy,(char *a, const char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(char*,strpbrk,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(char*,strrchr,(const char *a, int b),(a,b),return)
MACTRAMPOLINE(size_t,strspn,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(char*,strstr,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(char*,strtok,(char *a, const char *b),(a,b),return)
MACTRAMPOLINE(char*,strtok_r,(char *a, const char *b, char* *c),(a,b,c),return)
MACTRAMPOLINE(size_t,strxfrm,(char *a, const char *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,mlock,(const void *a, size_t b),(a,b),return)
MACTRAMPOLINE(int,mlockall,(int a),(a),return)
MACTRAMPOLINE(int,mprotect,(void *a, size_t b, int c),(a,b,c),return)
//MACTRAMPOLINE(int,msync,(void *a, size_t b, int c),(a,b,c),return)
MACTRAMPOLINE(int,munlock,(const void *a, size_t b),(a,b),return)
MACTRAMPOLINE(int,munlockall,(void),(),return)
MACTRAMPOLINE(int,munmap,(void *a, size_t b),(a,b),return)
//MACTRAMPOLINE(int,posix_madvise,(void *a, size_t b, int c),(a,b,c),return)
MACTRAMPOLINE(int,shm_unlink,(const char *a),(a),return)
MACTRAMPOLINE(key_t,ftok,(const char *a, int b),(a,b),return)
MACTRAMPOLINE(void*,shmat,(int a, const void *b, int c),(a,b,c),return)
//MACTRAMPOLINE(int,shmctl,(int a, int b, struct shmid_ds *c),(a,b,c),return)
MACTRAMPOLINE(int,shmdt,(const void *a),(a),return)
MACTRAMPOLINE(int,shmget,(key_t a, size_t b, int c),(a,b,c),return)
//MACTRAMPOLINE(int,semctl,(int a, int b, int c, ...),(a,b,c,d),return)
MACTRAMPOLINE(int,semget,(key_t a, int b, int c),(a,b,c),return)
//MACTRAMPOLINE(int,semop,(int a, struct sembuf *b, size_t c),(a,b,c),return)
MACTRAMPOLINE(int,getpriority,(int a, id_t b),(a,b),return)
// !!! FIXME: we don't have RUSAGE_THREAD on Mac OS X.
MACTRAMPOLINE(int,getrusage,(int a, struct rusage *b),(a,b),return)
MACTRAMPOLINE(int,setpriority,(int a, id_t b, int c),(a,b,c),return)
MACTRAMPOLINE(int,pselect,(int a, fd_set *b, fd_set *c, fd_set *d, const struct timespec *e, const sigset_t *f),(a,b,c,d,e,f),return)
MACTRAMPOLINE(int,select,(int a, fd_set *b, fd_set *c, fd_set *d, struct timeval *e),(a,b,c,d,e),return)
//MACTRAMPOLINE(int,getitimer,(int a, struct itimerval *b),(a,b),return)
//MACTRAMPOLINE(int,setitimer,(int a, const struct itimerval *b, struct itimerval *c),(a,b,c),return)
MACTRAMPOLINE(int,gettimeofday,(struct timeval *a, void *b),(a,b),return)
MACTRAMPOLINE(int,utimes,(const char *a, const struct timeval b[2]),(a,b),return)
//MACTRAMPOLINE(ssize_t,readv,(int a, const struct iovec *b, int c),(a,b,c),return)
//MACTRAMPOLINE(ssize_t,writev,(int a, const struct iovec *b, int c),(a,b,c),return)
//MACTRAMPOLINE(int,statvfs,(const char *a, struct statvfs *b),(a,b),return)
//MACTRAMPOLINE(int,fstatvfs,(int a, struct statvfs *b),(a,b),return)
MACTRAMPOLINE(pid_t,wait,(int *a),(a),return)
//MACTRAMPOLINE(pid_t,wait3,(int *a, int b, struct rusage *c),(a,b,c),return)
//MACTRAMPOLINE(int,waitid,(idtype_t a, id_t b, siginfo_t *c, int d),(a,b,c,d),return)
//MACTRAMPOLINE(int,msgctl,(int a, int b, struct msqid_ds *c),(a,b,c),return)
//MACTRAMPOLINE(int,msgget,(key_t a, int b),(a,b),return)
//MACTRAMPOLINE(ssize_t,msgrcv,(int a, void *b, size_t c, long int d, int e),(a,b,c,d,e),return)
//MACTRAMPOLINE(int,msgsnd,(int a, const void *b, size_t c, int d),(a,b,c,d),return)
//MACTRAMPOLINE(int,ftime,(struct timeb *a),(a),return)
MACTRAMPOLINE(int,listen,(int a, int b),(a,b),return)
//MACTRAMPOLINE(ssize_t,recvmsg,(int a, struct msghdr *b, int c),(a,b,c),return)
//MACTRAMPOLINE(ssize_t,sendmsg,(int a, const struct msghdr *b, int c),(a,b,c),return)
MACTRAMPOLINE(int,shutdown,(int a, int b),(a,b),return)

// This doesn't match up exactly with Linux, but it does for the things people care about (AF_UNIX, AF_INET, etc).
MACTRAMPOLINE(int,socket,(int a, int b, int c),(a,b,c),return)

//MACTRAMPOLINE(int,socketpair,(int a, int b, int c, int d[2]),(a,b,c,d),return)
MACTRAMPOLINE(int,sockatmark,(int a),(a),return)
//MACTRAMPOLINE(clock_t,times,(struct tms *a),(a),return)
MACTRAMPOLINE(in_addr_t,inet_addr,(const char *a),(a),return)
MACTRAMPOLINE(in_addr_t,inet_lnaof,(struct in_addr a),(a),return)
MACTRAMPOLINE(struct in_addr,inet_makeaddr,(in_addr_t a, in_addr_t b),(a,b),return)
MACTRAMPOLINE(in_addr_t,inet_netof,(struct in_addr a),(a),return)
MACTRAMPOLINE(in_addr_t,inet_network,(const char *a),(a),return)
MACTRAMPOLINE(char*,inet_ntoa,(struct in_addr a),(a),return)
MACTRAMPOLINE(int,inet_aton,(const char *a, struct in_addr *b),(a,b),return)
//MACTRAMPOLINE(int,dbm_clearerr,(DBM *a),(a),return)
//MACTRAMPOLINE(void,dbm_close,(DBM *a),(a),)
//MACTRAMPOLINE(int,dbm_delete,(DBM *a, datum b),(a,b),return)
//MACTRAMPOLINE(int,dbm_error,(DBM *a),(a),return)
//MACTRAMPOLINE(datum,dbm_fetch,(DBM *a, datum b),(a,b),return)
//MACTRAMPOLINE(datum,dbm_firstkey,(DBM *a),(a),return)
//MACTRAMPOLINE(datum,dbm_nextkey,(DBM *a),(a),return)
//MACTRAMPOLINE(int,dbm_store,(DBM *a, datum b, datum c, int d),(a,b,c,d),return)
//MACTRAMPOLINE(struct lconv*,localeconv,(void),(),return)
MACTRAMPOLINE(void,clearerr,(FILE *a),(a),)
MACTRAMPOLINE(int,fclose,(FILE *a),(a),return)
MACTRAMPOLINE(FILE*,fdopen,(int a, const char *b),(a,b),return)
MACTRAMPOLINE(int,feof,(FILE *a),(a),return)
MACTRAMPOLINE(int,ferror,(FILE *a),(a),return)
MACTRAMPOLINE(int,fflush,(FILE *a),(a),return)
MACTRAMPOLINE(int,fgetc,(FILE *a),(a),return)
MACTRAMPOLINE(int,fgetpos,(FILE *a, fpos_t *b),(a,b),return)
MACTRAMPOLINE(char*,fgets,(char *a, int b, FILE *c),(a,b,c),return)
MACTRAMPOLINE(int,fileno,(FILE *a),(a),return)
MACTRAMPOLINE(void,flockfile,(FILE *a),(a),)
MACTRAMPOLINE(FILE*,fopen,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(int,fputc,(int a, FILE *b),(a,b),return)
MACTRAMPOLINE(int,fputs,(const char *a, FILE *b),(a,b),return)
MACTRAMPOLINE(size_t,fread,(void *a, size_t b, size_t c, FILE *d),(a,b,c,d),return)
MACTRAMPOLINE(FILE*,freopen,(const char *a, const char *b, FILE *c),(a,b,c),return)
MACTRAMPOLINE(int,fseek,(FILE *a, long int b, int c),(a,b,c),return)
MACTRAMPOLINE(int,fsetpos,(FILE *a, const fpos_t *b),(a,b),return)
MACTRAMPOLINE(long int,ftell,(FILE *a),(a),return)
MACTRAMPOLINE(int,ftrylockfile,(FILE *a),(a),return)
MACTRAMPOLINE(void,funlockfile,(FILE *a),(a),)
//MACTRAMPOLINE(int,lockf,(int a, int b, off_t c),(a,b,c),return)
MACTRAMPOLINE(size_t,fwrite,(const void *a, size_t b, size_t c, FILE *d),(a,b,c,d),return)
MACTRAMPOLINE(int,getc,(FILE *a),(a),return)
MACTRAMPOLINE(int,getchar,(void),(),return)
MACTRAMPOLINE(int,getc_unlocked,(FILE *a),(a),return)
MACTRAMPOLINE(int,getchar_unlocked,(void),(),return)
MACTRAMPOLINE(char*,gets,(char *a),(a),return)
MACTRAMPOLINE(int,getw,(FILE *a),(a),return)
MACTRAMPOLINE(int,pclose,(FILE *a),(a),return)
MACTRAMPOLINE(void,perror,(const char *a),(a),)
MACTRAMPOLINE(FILE*,popen,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(int,putc,(int a, FILE *b),(a,b),return)
MACTRAMPOLINE(int,putchar,(int a),(a),return)
MACTRAMPOLINE(int,putc_unlocked,(int a, FILE *b),(a,b),return)
MACTRAMPOLINE(int,putchar_unlocked,(int a),(a),return)
MACTRAMPOLINE(int,puts,(const char *a),(a),return)
MACTRAMPOLINE(int,putw,(int a, FILE *b),(a,b),return)
MACTRAMPOLINE(int,remove,(const char *a),(a),return)
MACTRAMPOLINE(int,rename,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(void,rewind,(FILE *a),(a),)
MACTRAMPOLINE(void,setbuf,(FILE *a, char *b),(a,b),)
MACTRAMPOLINE(int,setvbuf,(FILE *a, char *b, int c, size_t d),(a,b,c,d),return)
MACTRAMPOLINE(char*,tempnam,(const char *a, const char *b),(a,b),return)
MACTRAMPOLINE(FILE*,tmpfile,(void),(),return)
MACTRAMPOLINE(char*,tmpnam,(char *a),(a),return)
MACTRAMPOLINE(int,ungetc,(int a, FILE *b),(a,b),return)
//MACTRAMPOLINE(struct group*,getgrgid,(gid_t a),(a),return)
//MACTRAMPOLINE(struct group*,getgrnam,(const char *a),(a),return)
//MACTRAMPOLINE(int,getgrgid_r,(gid_t a, struct group *b, char  *c, size_t d, struct group* *e),(a,b,c,d,e),return)
//MACTRAMPOLINE(int,getgrnam_r,(const char  *a, struct group  *b, char  *c, size_t d, struct group* *e),(a,b,c,d,e),return)
//MACTRAMPOLINE(struct group*,getgrent,(void),(),return)
//MACTRAMPOLINE(void,endgrent,(void),(),)
//MACTRAMPOLINE(void,setgrent,(void),(),)
//MACTRAMPOLINE(int,posix_spawnattr_destroy,(posix_spawnattr_t *a),(a),return)
//MACTRAMPOLINE(int,posix_spawnattr_getsigdefault,(const posix_spawnattr_t *a, sigset_t *b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_getflags,(const posix_spawnattr_t *a, short *b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_getpgroup,(const posix_spawnattr_t *a, pid_t *b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_getschedparam,(const posix_spawnattr_t *a, struct sched_param *b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_getschedpolicy,(const posix_spawnattr_t *a, int *b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_getsigmask,(const posix_spawnattr_t *a, sigset_t *b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_init,(posix_spawnattr_t *a),(a),return)
//MACTRAMPOLINE(int,posix_spawnattr_setsigdefault,(posix_spawnattr_t *a, const sigset_t *b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_setflags,(posix_spawnattr_t *a, short b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_setpgroup,(posix_spawnattr_t *a, pid_t b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_setschedparam,(posix_spawnattr_t *a, const struct sched_param *b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_setschedpolicy,(posix_spawnattr_t *a, int b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawnattr_setsigmask,(posix_spawnattr_t *a, const sigset_t *b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawn_file_actions_addclose,(posix_spawn_file_actions_t *a, int b),(a,b),return)
//MACTRAMPOLINE(int,posix_spawn_file_actions_adddup2,(posix_spawn_file_actions_t *a, int b, int c),(a,b,c),return)
//MACTRAMPOLINE(int,posix_spawn_file_actions_destroy,(posix_spawn_file_actions_t *a),(a),return)
//MACTRAMPOLINE(int,posix_spawn_file_actions_init,(posix_spawn_file_actions_t *a),(a),return)
//MACTRAMPOLINE(int,posix_spawn,(pid_t *a, const char *b, const posix_spawn_file_actions_t *c, const posix_spawnattr_t *d, char *const e[], char *const f[]),(a,b,c,d,e,f),return)
//MACTRAMPOLINE(int,posix_spawnp,(pid_t *a, const char *b, const posix_spawn_file_actions_t *c, const posix_spawnattr_t *d, char *const e[], char *const f[]),(a,b,c,d,e,f),return)

// end of mactrampolines.h ...
